@@ -1,19 +1,19 @@
-from django.conf.urls import url
+from django.urls import path
 from jnt_admin_tools.menu import views
 
 urlpatterns = [
-    url(
-        r"^add_bookmark/$",
+    path(
+        "add_bookmark/",
         views.add_bookmark,
         name="admin-tools-menu-add-bookmark",
     ),
-    url(
-        r"^edit_bookmark/(?P<id>.+)/$",
+    path(
+        "edit_bookmark/<int:id>/",
         views.edit_bookmark,
         name="admin-tools-menu-edit-bookmark",
     ),
-    url(
-        r"^remove_bookmark/(?P<id>.+)/$",
+    path(
+        "remove_bookmark/<int:id>/",
         views.remove_bookmark,
         name="admin-tools-menu-remove-bookmark",
     ),
